@@ -70,14 +70,23 @@ class Renderer:
         glyphLine = buildGlyphLine(infos, positions, glyphNames)
         orig_bounds = calcGlyphLineBounds(glyphLine, font)
         extents = self.font.hbFont.get_font_extents(buf.direction)
-        bounds = (0, extents.descender, orig_bounds[2], extents.ascender)
+        # bounds is a tuple defined as (xMin, yMin, xMax, yMax)
+        bounds = (
+            min(orig_bounds[0], orig_bounds[2]),
+            min(extents.descender, extents.ascender),
+            max(orig_bounds[0], orig_bounds[2]),
+            max(extents.descender, extents.ascender),
+        )
         bounds = scaleRect(bounds, scaleFactor, scaleFactor)
         bounds = insetRect(bounds, -self.margin, -self.margin)
         bounds = intRect(bounds)
         surfaceClass = getSurfaceClass("skia", ".png")
 
         surface = surfaceClass()
-        if orig_bounds[2] == 0 and orig_bounds[3] ==0:
+        # return empty canvas if either width or height == 0. Not doing so
+        # causes Skia to raise a null pointer error
+        if orig_bounds[0] == orig_bounds[2] or \
+            orig_bounds[1] == orig_bounds[3]:
             return Image.new("RGBA", (0,0))
         with surface.canvas(bounds) as canvas:
             canvas.scale(scaleFactor)
@@ -224,6 +233,7 @@ if __name__ == "__main__":
     parser.add_argument("--lang", metavar="LANGUAGE")
     parser.add_argument("--script", metavar="SCRIPT")
     parser.add_argument("--features", metavar="FEATURES")
+    parser.add_argument("--variations", metavar="VARIATIONS")
     parser.add_argument("-pt", help="point size", default=250, type=int)
     # TODO add variations
     args = parser.parse_args()
@@ -240,11 +250,19 @@ if __name__ == "__main__":
             else:
                 features[f] = True
 
+    variations = None
+    if args.variations:
+        variations = {}
+        for f in args.variations.split(","):
+            axis, loc = f.split("=")
+            variations[axis] = float(loc)
+
     img = Renderer(
         font,
         features=features,
         lang=args.lang,
         script=args.script,
         font_size=args.pt,
+        variations=variations
     ).render(args.string)
     img.save(args.out)
